@@ -7,26 +7,20 @@
  Copyright Henrik Bengtsson, 2014
  **************************************************************************/
 #include <Rdefines.h>
-#include "types.h"
-#include "utils.h"
+#include "000.types.h"
+#include "colRanges_lowlevel.h"
+#include "naming.h"
 
-#define METHOD colRanges
-#define RETURN_TYPE void
-#define ARGUMENTS_LIST X_C_TYPE *x, R_xlen_t nrow, R_xlen_t ncol, void *rows, R_xlen_t nrows, void *cols, R_xlen_t ncols, int what, int narm, int hasna, X_C_TYPE *ans, int *is_counted
-
-#define X_TYPE 'i'
-#include "templates-gen-matrix.h"
-#define X_TYPE 'r'
-#include "templates-gen-matrix.h"
-
-
-SEXP colRanges(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP what, SEXP naRm, SEXP hasNA) {
+SEXP colRanges(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP what, SEXP naRm, SEXP hasNA, SEXP useNames) {
   SEXP ans = NILSXP, ans2 = NILSXP;
   int *mins, *maxs;
   double *mins2, *maxs2;
   int *is_counted, all_counted = 0;
-  int what2, narm, hasna;
+  int what2, narm, hasna, usenames;
   R_xlen_t nrow, ncol, jj;
+  
+  /* Coercion moved down to C */
+  PROTECT(dim = coerceVector(dim, INTSXP));
 
   /* Argument 'x' and 'dim': */
   assertArgMatrix(x, dim, (R_TYPE_INT | R_TYPE_REAL), "x");
@@ -50,9 +44,11 @@ SEXP colRanges(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP what, SEXP naRm, SEX
 
   /* Argument 'rows' and 'cols': */
   R_xlen_t nrows, ncols;
-  int rowsType, colsType;
-  void *crows = validateIndices(rows, nrow, 0, &nrows, &rowsType);
-  void *ccols = validateIndices(cols, ncol, 0, &ncols, &colsType);
+  R_xlen_t *crows = validateIndices(rows, nrow, 0, &nrows);
+  R_xlen_t *ccols = validateIndices(cols, ncol, 0, &ncols);
+  
+  /* Argument 'useNames': */ 
+  usenames = asLogical(useNames);
 
   is_counted = (int *) R_alloc(ncols, sizeof(int));
 
@@ -62,7 +58,24 @@ SEXP colRanges(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP what, SEXP naRm, SEX
     } else {
       PROTECT(ans = allocVector(REALSXP, ncols));
     }
-    colRanges_Real[rowsType][colsType](REAL(x), nrow, ncol, crows, nrows, ccols, ncols, what2, narm, hasna, REAL(ans), is_counted);
+    colRanges_dbl(REAL(x), nrow, ncol, crows, nrows, ccols, ncols, what2, narm, hasna, REAL(ans), is_counted);
+    if (usenames != NA_LOGICAL && usenames){
+      SEXP dimnames = getAttrib(x, R_DimNamesSymbol);
+      if (dimnames != R_NilValue) {
+        if (what2 == 2) {
+          if (ncols != 0) {
+            /* colRanges() returns a numeric Kx2 matrix, reverse dimnames */
+            setDimnames(ans, dimnames, ncols, ccols, 0, crows, TRUE);
+          }
+          /* (else) Zero-length colnames attribute? Keep behavior same as base R function */
+        } else{
+          SEXP namesVec = VECTOR_ELT(dimnames, 1);
+          if (namesVec != R_NilValue) {
+            setNames(ans, namesVec, ncols, ccols);
+          }        
+        }
+      }
+    }
     UNPROTECT(1);
   } else if (isInteger(x)) {
     if (what2 == 2) {
@@ -70,7 +83,7 @@ SEXP colRanges(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP what, SEXP naRm, SEX
     } else {
       PROTECT(ans = allocVector(INTSXP, ncols));
     }
-    colRanges_Integer[rowsType][colsType](INTEGER(x), nrow, ncol, crows, nrows, ccols, ncols, what2, narm, hasna, INTEGER(ans), is_counted);
+    colRanges_int(INTEGER(x), nrow, ncol, crows, nrows, ccols, ncols, what2, narm, hasna, INTEGER(ans), is_counted);
 
     /* Any entries with zero non-missing values? */
     all_counted = 1;
@@ -128,9 +141,28 @@ SEXP colRanges(SEXP x, SEXP dim, SEXP rows, SEXP cols, SEXP what, SEXP naRm, SEX
 
       ans = ans2;
     }
+    if (usenames != NA_LOGICAL && usenames){
+      SEXP dimnames = getAttrib(x, R_DimNamesSymbol);
+      if (dimnames != R_NilValue) {
+        if (what2 == 2) {
+          if (ncols != 0) {
+            /* colRanges() returns a numeric Kx2 matrix, reverse dimnames */
+            setDimnames(ans, dimnames, ncols, ccols, 0, crows, TRUE);
+          }
+          /* (else) Zero-length colnames attribute? Keep behavior same as base R function */
+        } else{
+          SEXP namesVec = VECTOR_ELT(dimnames, 1);
+          if (namesVec != R_NilValue) {
+            setNames(ans, namesVec, ncols, ccols);
+          }        
+        }
+      }
+    }
 
     UNPROTECT(1); /* ans */
   }
+  
+  UNPROTECT(1); /* PROTECT(dim = ...) */
 
   return(ans);
 } // colRanges()
