@@ -15,16 +15,7 @@
  **************************************************************************/
 #include <Rdefines.h>
 #include <Rmath.h>
-#include "utils.h"
-
-
-#define METHOD logSumExp
-#define METHOD_NAME logSumExp_double
-#define RETURN_TYPE double
-#define ARGUMENTS_LIST double *x, void *idxs, R_xlen_t nidxs, int narm, int hasna, R_xlen_t by, double *xx
-
-#include "templates-gen-vector.h"
-
+#include "logSumExp_lowlevel.h"
 
 SEXP logSumExp(SEXP lx, SEXP idxs, SEXP naRm, SEXP hasNA) {
   int narm, hasna;
@@ -40,10 +31,9 @@ SEXP logSumExp(SEXP lx, SEXP idxs, SEXP naRm, SEXP hasNA) {
 
   /* Argument 'idxs': */
   R_xlen_t nidxs;
-  int idxsType;
-  void *cidxs = validateIndices(idxs, xlength(lx), 1, &nidxs, &idxsType);
+  R_xlen_t *cidxs = validateIndices(idxs, xlength(lx), 1, &nidxs);
 
-  return(Rf_ScalarReal(logSumExp_double[idxsType](REAL(lx), cidxs, nidxs, narm, hasna, 0, NULL)));
+  return(Rf_ScalarReal(logSumExp_double(REAL(lx), cidxs, nidxs, narm, hasna, 0, NULL)));
 } /* logSumExp() */
 
 
